==> struts-2.5.33-src.zip: struts-2.5.33/src/core/src/test/java/org/apache/struts2/ExecutionCountTestAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2;

import com.opensymphony.xwork2.ActionSupport;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;


/**
 * ExecutionCountTestAction
 */
public class ExecutionCountTestAction extends ActionSupport {

    private static final long serialVersionUID = -2954211394678430609L;


    private static final Logger LOG = LogManager.getLogger(ExecutionCountTestAction.class);


    private int executionCount = 0;


    public int getExecutionCount() {
        return executionCount;
    }

    public String execute() throws Exception {
        executionCount++;
        LOG.info("executing ExecutionCountTestAction. Current count is " + executionCount);

        return SUCCESS;
    }
}

==> struts-6.8.0-src.zip: struts-6.8.0/src/core/src/test/java/org/apache/struts2/ExecutionCountTestAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2;

import com.opensymphony.xwork2.ActionSupport;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;


/**
 * ExecutionCountTestAction
 */
public class ExecutionCountTestAction extends ActionSupport {

    private static final long serialVersionUID = -2954211394678430609L;


    private static final Logger LOG = LogManager.getLogger(ExecutionCountTestAction.class);


    private int executionCount = 0;


    public int getExecutionCount() {
        return executionCount;
    }

    @Override
    public String execute() throws Exception {
        executionCount++;
        LOG.info("executing ExecutionCountTestAction. Current count is {}", executionCount);

        return SUCCESS;
    }
}
